==> jc-1.4.0.tar.gz: java/awt/Panel.h <==
// public class java.awt.Panel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class a52c288050fd199 java_awt_Panel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_java_awt_Panel_H_
#define _JC_java_awt_Panel_H_

// Forward structure declarations
struct _jc_java_awt_LayoutManager$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_Panel$sub_refs	_jc_java_awt_Panel$sub_refs;
typedef struct _jc_java_awt_Panel$sub_nonrefs	_jc_java_awt_Panel$sub_nonrefs;
typedef struct _jc_java_awt_Panel$refs	_jc_java_awt_Panel$refs;
typedef struct _jc_java_awt_Panel$nonrefs	_jc_java_awt_Panel$nonrefs;
typedef struct _jc_java_awt_Panel$object	_jc_java_awt_Panel$object;

typedef struct _jc_java_awt_Panel$fields_struct	_jc_java_awt_Panel$fields_struct;
typedef const struct _jc_java_awt_Panel$vmethods	_jc_java_awt_Panel$vmethods;
typedef const struct _jc_java_awt_Panel$vtable	_jc_java_awt_Panel$vtable;
typedef const struct _jc_java_awt_Panel$vtype	_jc_java_awt_Panel$vtype;

// Class fields structure
struct _jc_java_awt_Panel$fields_struct {
	jlong	next__5fpanel__5fnumber;
	jlong	serialVersionUID;
};
extern _jc_java_awt_Panel$fields_struct _jc_java_awt_Panel$class_fields;

// Constructors
extern void _jc_java_awt_Panel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Panel$object *);
extern void _jc_java_awt_Panel$method$_init$72f3670f2e67120b(_jc_env *, struct _jc_java_awt_Panel$object *, struct _jc_object *);

// Virtual methods
extern void _jc_java_awt_Panel$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_Panel$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Panel$method$generateName$376b749827684628(_jc_env *, struct _jc_java_awt_Panel$object *);
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_Panel$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_Panel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Panel$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_Panel$method_info$generateName$376b749827684628;
extern _jc_method _jc_java_awt_Panel$method_info$getAccessibleContext$99df33b6e138b2ea;

// Static methods
extern jlong _jc_java_awt_Panel$method$getUniqueLong$4b67b0d02eb75075(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_Panel$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_Panel$object *);
	struct _jc_java_lang_String$object	*(*generateName$376b749827684628)(_jc_env *, struct _jc_java_awt_Panel$object *);
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_Panel$object *);
};

// Vtable
struct _jc_java_awt_Panel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Panel$vmethods	java_awt_Panel;
};

// Vtype
struct _jc_java_awt_Panel$vtype {
	_jc_type			type;
	_jc_java_awt_Panel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Panel$sub_refs {
	struct _jc_javax_accessibility_AccessibleContext$object	*context;
};

// Reference instance fields (object)
struct _jc_java_awt_Panel$refs {
    _jc_java_awt_Panel$sub_refs	java_awt_Panel;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Panel$sub_nonrefs {
	jboolean	initialSystemUpdateDone;
	jboolean	initialUpdateConsumed;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Panel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Panel$sub_nonrefs	java_awt_Panel;
};

// Object instance structure
struct _jc_java_awt_Panel$object {
	_jc_java_awt_Panel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Panel$vtype	*vtype;
	_jc_java_awt_Panel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Panel$vtype _jc_java_awt_Panel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Panel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Panel$class_object;

#endif	/* _JC_java_awt_Panel_H_ */

==> jc-1.4.5.tar.gz: java/awt/Panel.h <==
// public class java.awt.Panel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class a52c288050fd199 java_awt_Panel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Container

#include "java/awt/Container.h"

#ifndef _JC_java_awt_Panel_H_
#define _JC_java_awt_Panel_H_

// Forward structure declarations
struct _jc_java_awt_LayoutManager$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;

// Typedefs
typedef struct _jc_java_awt_Panel$sub_refs	_jc_java_awt_Panel$sub_refs;
typedef struct _jc_java_awt_Panel$sub_nonrefs	_jc_java_awt_Panel$sub_nonrefs;
typedef struct _jc_java_awt_Panel$refs	_jc_java_awt_Panel$refs;
typedef struct _jc_java_awt_Panel$nonrefs	_jc_java_awt_Panel$nonrefs;
typedef struct _jc_java_awt_Panel$object	_jc_java_awt_Panel$object;

typedef struct _jc_java_awt_Panel$fields_struct	_jc_java_awt_Panel$fields_struct;
typedef const struct _jc_java_awt_Panel$vmethods	_jc_java_awt_Panel$vmethods;
typedef const struct _jc_java_awt_Panel$vtable	_jc_java_awt_Panel$vtable;
typedef const struct _jc_java_awt_Panel$vtype	_jc_java_awt_Panel$vtype;

// Class fields structure
struct _jc_java_awt_Panel$fields_struct {
	jlong	next__5fpanel__5fnumber;
	jlong	serialVersionUID;
};
extern _jc_java_awt_Panel$fields_struct _jc_java_awt_Panel$class_fields;

// Constructors
extern void _jc_java_awt_Panel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Panel$method$_init$72f3670f2e67120b(_jc_env *, struct _jc_java_awt_Panel$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Panel$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Panel$method$generateName$376b749827684628(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_Panel$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Panel$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_java_awt_Panel$method_info$generateName$376b749827684628;
extern _jc_method _jc_java_awt_Panel$method_info$getAccessibleContext$99df33b6e138b2ea;

// Static methods
extern jlong _jc_java_awt_Panel$method$getUniqueLong$4b67b0d02eb75075(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_Panel$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*generateName$376b749827684628)(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Panel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Panel$vmethods	java_awt_Panel;
};

// Vtype
struct _jc_java_awt_Panel$vtype {
	_jc_type			type;
	_jc_java_awt_Panel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Panel$sub_refs {
	struct _jc_javax_accessibility_AccessibleContext$object	*context;
};

// Reference instance fields (object)
struct _jc_java_awt_Panel$refs {
    _jc_java_awt_Panel$sub_refs	java_awt_Panel;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Panel$sub_nonrefs {
	jboolean	initialSystemUpdateDone;
	jboolean	initialUpdateConsumed;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Panel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Panel$sub_nonrefs	java_awt_Panel;
};

// Object instance structure
struct _jc_java_awt_Panel$object {
	_jc_java_awt_Panel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Panel$vtype	*vtype;
	_jc_java_awt_Panel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Panel$vtype _jc_java_awt_Panel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Panel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Panel$class_object;

#endif	/* _JC_java_awt_Panel_H_ */
